package org.scalatest.inspectors.atMost

import org.scalatest._
import org.scalatest.matchers.{BePropertyMatcher, BePropertyMatchResult, HavePropertyMatcher, HavePropertyMatchResult}
import collection.GenTraversable
import collection.GenMap
class InspectorShorthandsForAtMostFailedSpec7 extends Spec with Matchers with SharedHelpers {
  class EmptyBePropertyMatcher extends BePropertyMatcher[String] {
    def apply(left: String) = BePropertyMatchResult(left.isEmpty, "empty")
  }
  class StringLengthMatcher(expectedValue: Int) extends HavePropertyMatcher[String, Int] {
    def apply(value: String) = {
      new HavePropertyMatchResult(value.length == expectedValue, "length", expectedValue, value.length)
    }
  }
  val empty = new EmptyBePropertyMatcher()
  def plength(expectedValue: Int) = new StringLengthMatcher(expectedValue)
  val theInstance = "2"
  def arrayToString(xs: GenTraversable[_]): String = xs.toString
  def checkErrorAndCause(e: exceptions.TestFailedException, assertLineNumber: Int, fileName: String, errorMessage: String, causeErrorMessage: String) {
    assert(e.failedCodeFileName == Some(fileName), e.failedCodeFileName + " did not equal " + Some(fileName))
    assert(e.failedCodeLineNumber == Some(assertLineNumber), e.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
    assert(e.message == Some(errorMessage), e.message + " did not equal " + Some(
  errorMessage))
    e.getCause match {
      case tfe: exceptions.TestFailedException =>
        assert(tfe.failedCodeFileName == Some(fileName), tfe.failedCodeFileName + " did not equal " + Some(fileName))
        assert(tfe.failedCodeLineNumber == Some(assertLineNumber), tfe.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
        assert(tfe.message == Some(causeErrorMessage), tfe.message + " did not equal " + Some(causeErrorMessage))
        assert(tfe.getCause == null, tfe.getCause + " was not null")
      case other => fail("Expected cause to be TestFailedException, but got: " + other)
    }
  }
  def checkError(e: exceptions.TestFailedException, assertLineNumber: Int, fileName: String, errorMessage: String) {
    assert(e.failedCodeFileName == Some(fileName), e.failedCodeFileName + " did not equal " + Some(fileName))
    assert(e.failedCodeLineNumber == Some(assertLineNumber), e.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
    assert(e.message == Some(errorMessage), e.message + " did not equal " + Some(
  errorMessage))
  }
  def equal[T](left: T, right: T): Boolean = left == right
  def javaArrayList[T](valueList: List[T]): java.util.ArrayList[T] = {
    val col = new java.util.ArrayList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaHashSet[T](valueList: List[T]): java.util.HashSet[T] = {
    val col = new java.util.HashSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedList[T](valueList: List[T]): java.util.LinkedList[T] = {
    val col = new java.util.LinkedList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaStack[T](valueList: List[T]): java.util.Stack[T] = {
    val col = new java.util.Stack[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaTreeSet[T](valueList: List[T]): java.util.TreeSet[T] = {
    val col = new java.util.TreeSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaVector[T](valueList: List[T]): java.util.Vector[T] = {
    val col = new java.util.Vector[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaArrayBlockingQueue[T](valueList: List[T], size: Int): java.util.concurrent.ArrayBlockingQueue[T] = {
    val col = new java.util.concurrent.ArrayBlockingQueue[T](size)
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaArrayDeque[T](valueList: List[T]): java.util.ArrayDeque[T] = {
    val col = new java.util.ArrayDeque[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaConcurrentLinkedQueue[T](valueList: List[T]): java.util.concurrent.ConcurrentLinkedQueue[T] = {
    val col = new java.util.concurrent.ConcurrentLinkedQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaConcurrentSkipListSet[T](valueList: List[T]): java.util.concurrent.ConcurrentSkipListSet[T] = {
    val col = new java.util.concurrent.ConcurrentSkipListSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaCopyOnWriteArrayList[T](valueList: List[T]): java.util.concurrent.CopyOnWriteArrayList[T] = {
    val col = new java.util.concurrent.CopyOnWriteArrayList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaCopyOnWriteArraySet[T](valueList: List[T]): java.util.concurrent.CopyOnWriteArraySet[T] = {
    val col = new java.util.concurrent.CopyOnWriteArraySet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedBlockingDeque[T](valueList: List[T]): java.util.concurrent.LinkedBlockingDeque[T] = {
    val col = new java.util.concurrent.LinkedBlockingDeque[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedBlockingQueue[T](valueList: List[T]): java.util.concurrent.LinkedBlockingQueue[T] = {
    val col = new java.util.concurrent.LinkedBlockingQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedHashSet[T](valueList: List[T]): java.util.LinkedHashSet[T] = {
    val col = new java.util.LinkedHashSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaPriorityBlockingQueue[T](valueList: List[T]): java.util.concurrent.PriorityBlockingQueue[T] = {
    val col = new java.util.concurrent.PriorityBlockingQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaPriorityQueue[T](valueList: List[T]): java.util.PriorityQueue[T] = {
    val col = new java.util.PriorityQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaHashMap[K, V](valueMap: Map[K, V]): java.util.HashMap[K, V] = {
    val map = new java.util.HashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaTreeMap[K, V](valueMap: Map[K, V]): java.util.TreeMap[K, V] = {
    val map = new java.util.TreeMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaHashtable[K, V](valueMap: Map[K, V]): java.util.Hashtable[K, V] = {
    val map = new java.util.Hashtable[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaConcurrentHashMap[K, V](valueMap: Map[K, V]): java.util.concurrent.ConcurrentHashMap[K, V] = {
    val map = new java.util.concurrent.ConcurrentHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaConcurrentSkipListMap[K, V](valueMap: Map[K, V]): java.util.concurrent.ConcurrentSkipListMap[K, V] = {
    val map = new java.util.concurrent.ConcurrentSkipListMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaLinkedHashMap[K, V](valueMap: Map[K, V]): java.util.LinkedHashMap[K, V] = {
    val map = new java.util.LinkedHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaWeakHashMap[K, V](valueMap: Map[K, V]): java.util.WeakHashMap[K, V] = {
    val map = new java.util.WeakHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaProperties(valueMap: Map[String, String]): java.util.Properties = {
    val map = new java.util.Properties()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def `IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Set(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Seq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityBlockingQueue(List("hi")), javaPriorityBlockingQueue(List("boom!")), javaPriorityBlockingQueue(List.empty[String]), javaPriorityBlockingQueue(List("great!")), javaPriorityBlockingQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + arrayToString(xs))
  }
  def `Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Array(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + arrayToString(xs))
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Vector(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Set(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Seq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotIsEmpty[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeEqual[String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColSizeNotEqual[String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaPriorityQueue(List("hi")), javaPriorityQueue(List("boom!")), javaPriorityQueue(List.empty[String]), javaPriorityQueue(List("great!")), javaPriorityQueue(List("hi", "cool!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaColNotContain[String](xs, "hi", 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + arrayToString(xs))
  }
  def `Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + arrayToString(xs))
  }
  def `Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + arrayToString(xs))
  }
  def `Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Array(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + arrayToString(xs))
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Vector(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Set(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Seq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "boom!")), javaHashMap(Map("h" -> "hello!")), javaHashMap(Map.empty[String, String]), javaHashMap(Map("b" -> "hello!")), javaHashMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + arrayToString(xs))
  }
  def `Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + arrayToString(xs))
  }
  def `Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + arrayToString(xs))
  }
  def `Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + arrayToString(xs))
  }
  def `Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Array(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + arrayToString(xs))
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Vector(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!")))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotContainValue[String, String](xs, "boom!", 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapNotIsEmpty[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have size 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should have length 1
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeEqual[String, String](xs, 1, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapSizeNotEqual[String, String](xs, 0, 2) + " in " + xs)
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")), javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "hello!")), javaTreeMap(Map("h" -> "boom!"))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      atMost(1, xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForAtMostFailedSpec7.scala", "forAtMost(1) failed, because 2 elements satisfied the assertion block at " + failEarlySucceededIndexesJavaMapContainKey[String, String](xs, "b", 2) + " in " + xs)
  }
}
