package org.scalatest.inspectors.between

import org.scalatest._
import org.scalatest.matchers.{BePropertyMatcher, BePropertyMatchResult, HavePropertyMatcher, HavePropertyMatchResult}
import collection.GenTraversable
import collection.GenMap
class InspectorShorthandsForBetweenFailedSpec5 extends Spec with Matchers with SharedHelpers {
  class EmptyBePropertyMatcher extends BePropertyMatcher[String] {
    def apply(left: String) = BePropertyMatchResult(left.isEmpty, "empty")
  }
  class StringLengthMatcher(expectedValue: Int) extends HavePropertyMatcher[String, Int] {
    def apply(value: String) = {
      new HavePropertyMatchResult(value.length == expectedValue, "length", expectedValue, value.length)
    }
  }
  val empty = new EmptyBePropertyMatcher()
  def plength(expectedValue: Int) = new StringLengthMatcher(expectedValue)
  val theInstance = "2"
  def arrayToString(xs: GenTraversable[_]): String = xs.toString
  def checkErrorAndCause(e: exceptions.TestFailedException, assertLineNumber: Int, fileName: String, errorMessage: String, causeErrorMessage: String) {
    assert(e.failedCodeFileName == Some(fileName), e.failedCodeFileName + " did not equal " + Some(fileName))
    assert(e.failedCodeLineNumber == Some(assertLineNumber), e.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
    assert(e.message == Some(errorMessage), e.message + " did not equal " + Some(
  errorMessage))
    e.getCause match {
      case tfe: exceptions.TestFailedException =>
        assert(tfe.failedCodeFileName == Some(fileName), tfe.failedCodeFileName + " did not equal " + Some(fileName))
        assert(tfe.failedCodeLineNumber == Some(assertLineNumber), tfe.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
        assert(tfe.message == Some(causeErrorMessage), tfe.message + " did not equal " + Some(causeErrorMessage))
        assert(tfe.getCause == null, tfe.getCause + " was not null")
      case other => fail("Expected cause to be TestFailedException, but got: " + other)
    }
  }
  def checkError(e: exceptions.TestFailedException, assertLineNumber: Int, fileName: String, errorMessage: String) {
    assert(e.failedCodeFileName == Some(fileName), e.failedCodeFileName + " did not equal " + Some(fileName))
    assert(e.failedCodeLineNumber == Some(assertLineNumber), e.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
    assert(e.message == Some(errorMessage), e.message + " did not equal " + Some(
  errorMessage))
  }
  def equal[T](left: T, right: T): Boolean = left == right
  def javaArrayList[T](valueList: List[T]): java.util.ArrayList[T] = {
    val col = new java.util.ArrayList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaHashSet[T](valueList: List[T]): java.util.HashSet[T] = {
    val col = new java.util.HashSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedList[T](valueList: List[T]): java.util.LinkedList[T] = {
    val col = new java.util.LinkedList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaStack[T](valueList: List[T]): java.util.Stack[T] = {
    val col = new java.util.Stack[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaTreeSet[T](valueList: List[T]): java.util.TreeSet[T] = {
    val col = new java.util.TreeSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaVector[T](valueList: List[T]): java.util.Vector[T] = {
    val col = new java.util.Vector[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaArrayBlockingQueue[T](valueList: List[T], size: Int): java.util.concurrent.ArrayBlockingQueue[T] = {
    val col = new java.util.concurrent.ArrayBlockingQueue[T](size)
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaArrayDeque[T](valueList: List[T]): java.util.ArrayDeque[T] = {
    val col = new java.util.ArrayDeque[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaConcurrentLinkedQueue[T](valueList: List[T]): java.util.concurrent.ConcurrentLinkedQueue[T] = {
    val col = new java.util.concurrent.ConcurrentLinkedQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaConcurrentSkipListSet[T](valueList: List[T]): java.util.concurrent.ConcurrentSkipListSet[T] = {
    val col = new java.util.concurrent.ConcurrentSkipListSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaCopyOnWriteArrayList[T](valueList: List[T]): java.util.concurrent.CopyOnWriteArrayList[T] = {
    val col = new java.util.concurrent.CopyOnWriteArrayList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaCopyOnWriteArraySet[T](valueList: List[T]): java.util.concurrent.CopyOnWriteArraySet[T] = {
    val col = new java.util.concurrent.CopyOnWriteArraySet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedBlockingDeque[T](valueList: List[T]): java.util.concurrent.LinkedBlockingDeque[T] = {
    val col = new java.util.concurrent.LinkedBlockingDeque[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedBlockingQueue[T](valueList: List[T]): java.util.concurrent.LinkedBlockingQueue[T] = {
    val col = new java.util.concurrent.LinkedBlockingQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedHashSet[T](valueList: List[T]): java.util.LinkedHashSet[T] = {
    val col = new java.util.LinkedHashSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaPriorityBlockingQueue[T](valueList: List[T]): java.util.concurrent.PriorityBlockingQueue[T] = {
    val col = new java.util.concurrent.PriorityBlockingQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaPriorityQueue[T](valueList: List[T]): java.util.PriorityQueue[T] = {
    val col = new java.util.PriorityQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaHashMap[K, V](valueMap: Map[K, V]): java.util.HashMap[K, V] = {
    val map = new java.util.HashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaTreeMap[K, V](valueMap: Map[K, V]): java.util.TreeMap[K, V] = {
    val map = new java.util.TreeMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaHashtable[K, V](valueMap: Map[K, V]): java.util.Hashtable[K, V] = {
    val map = new java.util.Hashtable[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaConcurrentHashMap[K, V](valueMap: Map[K, V]): java.util.concurrent.ConcurrentHashMap[K, V] = {
    val map = new java.util.concurrent.ConcurrentHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaConcurrentSkipListMap[K, V](valueMap: Map[K, V]): java.util.concurrent.ConcurrentSkipListMap[K, V] = {
    val map = new java.util.concurrent.ConcurrentSkipListMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaLinkedHashMap[K, V](valueMap: Map[K, V]): java.util.LinkedHashMap[K, V] = {
    val map = new java.util.LinkedHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaWeakHashMap[K, V](valueMap: Map[K, V]): java.util.WeakHashMap[K, V] = {
    val map = new java.util.WeakHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaProperties(valueMap: Map[String, String]): java.util.Properties = {
    val map = new java.util.Properties()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Array(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Vector(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Set(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Seq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaVector(List("hi")), javaVector(List("boom!")), javaVector(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Array(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Vector(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Set(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Seq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayBlockingQueue(List("hi"), 3), javaArrayBlockingQueue(List("boom!"), 3), javaArrayBlockingQueue(List.empty[String], 3)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Array(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Vector(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Set(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String]))).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.Seq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = collection.mutable.IndexedSeq(javaArrayDeque(List("hi")), javaArrayDeque(List("boom!")), javaArrayDeque(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Array(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = IndexedSeq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])) should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Vector(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String]))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = Set(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should contain' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not contain' failed` {
    val xs = List(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotContain[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColContain[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should be symbol' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColNotIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not be symbol' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesJavaColNotIsEmpty[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColIsEmpty[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have size' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have size' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should have length' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeEqual[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeNotEqual[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par should throw TestFailedException with correct stack depth and message when 'java collection should not have length' failed` {
    val xs = Seq(javaConcurrentLinkedQueue(List("hi")), javaConcurrentLinkedQueue(List("boom!")), javaConcurrentLinkedQueue(List.empty[String])).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      between(7, 8, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForBetweenFailedSpec5.scala", "forBetween(7, 8) failed, because only 1 element satisfied the assertion block at " + succeededIndexesJavaColSizeNotEqual[String](xs, 1) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForBetweenFailedSpec5.scala:" + assertLineNumber + ")").format(indexElementJavaColSizeEqual[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
}
