package org.scalatest.inspectors.exactly

import org.scalatest._
import org.scalatest.matchers.{BePropertyMatcher, BePropertyMatchResult, HavePropertyMatcher, HavePropertyMatchResult}
import collection.GenTraversable
import collection.GenMap
class InspectorShorthandsForExactlyFailedSpec1 extends Spec with Matchers with SharedHelpers {
  class EmptyBePropertyMatcher extends BePropertyMatcher[String] {
    def apply(left: String) = BePropertyMatchResult(left.isEmpty, "empty")
  }
  class StringLengthMatcher(expectedValue: Int) extends HavePropertyMatcher[String, Int] {
    def apply(value: String) = {
      new HavePropertyMatchResult(value.length == expectedValue, "length", expectedValue, value.length)
    }
  }
  val empty = new EmptyBePropertyMatcher()
  def plength(expectedValue: Int) = new StringLengthMatcher(expectedValue)
  val theInstance = "2"
  def arrayToString(xs: GenTraversable[_]): String = xs.toString
  def checkErrorAndCause(e: exceptions.TestFailedException, assertLineNumber: Int, fileName: String, errorMessage: String, causeErrorMessage: String) {
    assert(e.failedCodeFileName == Some(fileName), e.failedCodeFileName + " did not equal " + Some(fileName))
    assert(e.failedCodeLineNumber == Some(assertLineNumber), e.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
    assert(e.message == Some(errorMessage), e.message + " did not equal " + Some(
  errorMessage))
    e.getCause match {
      case tfe: exceptions.TestFailedException =>
        assert(tfe.failedCodeFileName == Some(fileName), tfe.failedCodeFileName + " did not equal " + Some(fileName))
        assert(tfe.failedCodeLineNumber == Some(assertLineNumber), tfe.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
        assert(tfe.message == Some(causeErrorMessage), tfe.message + " did not equal " + Some(causeErrorMessage))
        assert(tfe.getCause == null, tfe.getCause + " was not null")
      case other => fail("Expected cause to be TestFailedException, but got: " + other)
    }
  }
  def checkError(e: exceptions.TestFailedException, assertLineNumber: Int, fileName: String, errorMessage: String) {
    assert(e.failedCodeFileName == Some(fileName), e.failedCodeFileName + " did not equal " + Some(fileName))
    assert(e.failedCodeLineNumber == Some(assertLineNumber), e.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
    assert(e.message == Some(errorMessage), e.message + " did not equal " + Some(
  errorMessage))
  }
  def equal[T](left: T, right: T): Boolean = left == right
  def javaArrayList[T](valueList: List[T]): java.util.ArrayList[T] = {
    val col = new java.util.ArrayList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaHashSet[T](valueList: List[T]): java.util.HashSet[T] = {
    val col = new java.util.HashSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedList[T](valueList: List[T]): java.util.LinkedList[T] = {
    val col = new java.util.LinkedList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaStack[T](valueList: List[T]): java.util.Stack[T] = {
    val col = new java.util.Stack[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaTreeSet[T](valueList: List[T]): java.util.TreeSet[T] = {
    val col = new java.util.TreeSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaVector[T](valueList: List[T]): java.util.Vector[T] = {
    val col = new java.util.Vector[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaArrayBlockingQueue[T](valueList: List[T], size: Int): java.util.concurrent.ArrayBlockingQueue[T] = {
    val col = new java.util.concurrent.ArrayBlockingQueue[T](size)
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaArrayDeque[T](valueList: List[T]): java.util.ArrayDeque[T] = {
    val col = new java.util.ArrayDeque[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaConcurrentLinkedQueue[T](valueList: List[T]): java.util.concurrent.ConcurrentLinkedQueue[T] = {
    val col = new java.util.concurrent.ConcurrentLinkedQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaConcurrentSkipListSet[T](valueList: List[T]): java.util.concurrent.ConcurrentSkipListSet[T] = {
    val col = new java.util.concurrent.ConcurrentSkipListSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaCopyOnWriteArrayList[T](valueList: List[T]): java.util.concurrent.CopyOnWriteArrayList[T] = {
    val col = new java.util.concurrent.CopyOnWriteArrayList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaCopyOnWriteArraySet[T](valueList: List[T]): java.util.concurrent.CopyOnWriteArraySet[T] = {
    val col = new java.util.concurrent.CopyOnWriteArraySet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedBlockingDeque[T](valueList: List[T]): java.util.concurrent.LinkedBlockingDeque[T] = {
    val col = new java.util.concurrent.LinkedBlockingDeque[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedBlockingQueue[T](valueList: List[T]): java.util.concurrent.LinkedBlockingQueue[T] = {
    val col = new java.util.concurrent.LinkedBlockingQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedHashSet[T](valueList: List[T]): java.util.LinkedHashSet[T] = {
    val col = new java.util.LinkedHashSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaPriorityBlockingQueue[T](valueList: List[T]): java.util.concurrent.PriorityBlockingQueue[T] = {
    val col = new java.util.concurrent.PriorityBlockingQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaPriorityQueue[T](valueList: List[T]): java.util.PriorityQueue[T] = {
    val col = new java.util.PriorityQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaHashMap[K, V](valueMap: Map[K, V]): java.util.HashMap[K, V] = {
    val map = new java.util.HashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaTreeMap[K, V](valueMap: Map[K, V]): java.util.TreeMap[K, V] = {
    val map = new java.util.TreeMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaHashtable[K, V](valueMap: Map[K, V]): java.util.Hashtable[K, V] = {
    val map = new java.util.Hashtable[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaConcurrentHashMap[K, V](valueMap: Map[K, V]): java.util.concurrent.ConcurrentHashMap[K, V] = {
    val map = new java.util.concurrent.ConcurrentHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaConcurrentSkipListMap[K, V](valueMap: Map[K, V]): java.util.concurrent.ConcurrentSkipListMap[K, V] = {
    val map = new java.util.concurrent.ConcurrentSkipListMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaLinkedHashMap[K, V](valueMap: Map[K, V]): java.util.LinkedHashMap[K, V] = {
    val map = new java.util.LinkedHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaWeakHashMap[K, V](valueMap: Map[K, V]): java.util.WeakHashMap[K, V] = {
    val map = new java.util.WeakHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaProperties(valueMap: Map[String, String]): java.util.Properties = {
    val map = new java.util.Properties()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had its expected value 0, on object \"{1}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had its expected value 0, on object \"{1}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had its expected value 0, on object \"{1}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi") should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had its expected value 0, on object \"{1}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = collection.mutable.Set("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had its expected value 0, on object \"{1}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("", "boom!", "hi")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had its expected value 0, on object \"{1}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = collection.mutable.Seq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was a empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesIsEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsNotEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesIsNotEmpty(xs, "") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was an empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementIsEmpty(itr, xs, "")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had value {1}, instead of its expected value 0, on object \"{2}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqualLength(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, The length property had its expected value 0, on object \"{1}\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesLengthEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesLengthNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementLengthEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("", "boom!", "hi").par should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = collection.mutable.IndexedSeq("", "boom!", "hi").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqual(xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" had size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqual(itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = Set("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `Set("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = Set("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `List("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = List("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `List("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = List("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `Seq("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = Seq("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `Seq("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = Seq("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `Array("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = Array("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + "WrappedArray(1, 2, 3)")
  }
  def `Array("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = Array("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + "WrappedArray(1, 2, 3)")
  }
  def `IndexedSeq("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = IndexedSeq("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = IndexedSeq("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `Vector("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = Vector("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `Vector("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = Vector("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `Set("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = Set("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `Set("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = Set("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `List("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = List("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `List("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = List("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `Seq("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = Seq("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `Seq("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = Seq("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = IndexedSeq("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = IndexedSeq("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = collection.mutable.Set("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = collection.mutable.Set("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = collection.mutable.Seq("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = collection.mutable.Seq("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = collection.mutable.IndexedSeq("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("1", theInstance, "3") should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = collection.mutable.IndexedSeq("1", theInstance, "3")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = collection.mutable.Set("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = collection.mutable.Set("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("1", theInstance, "3")).par should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("1", theInstance, "3")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("1", theInstance, "3")).par should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("1", theInstance, "3")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = collection.mutable.Seq("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = collection.mutable.Seq("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should be theSameInstanceAs' failed` {
    val xs = collection.mutable.IndexedSeq("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be theSameInstanceAs theInstance
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was not the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("1", theInstance, "3").par should throw TestFailedException with correct stack depth and message when 'should not be theSameInstanceAs' failed` {
    val xs = collection.mutable.IndexedSeq("1", theInstance, "3").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be theSameInstanceAs (theInstance)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotRefEqual[String](xs, theInstance) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" was the same instance as \"2\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementRefEqual[String](itr, xs, theInstance)) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `Array("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = Array("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + "WrappedArray(hello A!, hi B, hello C!)")
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `Vector("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = Vector("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `List("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = List("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!") should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!")
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = collection.mutable.Set("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("hello A!", "hi B", "hello C!")).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = collection.mutable.Seq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith ("hello")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with substring \"hello\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with substring \"!\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring \"ell\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should startWith regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should startWith regex "hel*o"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not start with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not startWith regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not startWith regex ("hel*o")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotStartsWith(xs, "hello") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" started with a substring that matched the regular expression hel*o (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementStartsWith(itr, xs, "hello")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should endWith regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should endWith regex "!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not end with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not endWith regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not endWith regex ("!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotEndsWith(xs, "!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" ended with a substring that matched the regular expression ! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementEndsWith(itr, xs, "!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should include regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should include regex "ell"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not include substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not include regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not include regex ("ell")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotInclude(xs, "ell") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" included substring that matched regex ell (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementInclude(itr, xs, "ell")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should fullyMatch regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should fullyMatch regex "h.*!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" did not fully match the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par should throw TestFailedException with correct stack depth and message when 'should not fullyMatch regex' failed` {
    val xs = collection.mutable.IndexedSeq("hello A!", "hi B", "hello C!").par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not fullyMatch regex ("h.*!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesNotMatches(xs, "h.*!") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, \"{1}\" fully matched the regular expression h.*! (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementMatches(itr, xs, "h.*!")) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi"), Set("boom!"), Set()) should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = Set(Set("hi"), Set("boom!"), Set())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi"), Set("boom!"), Set()) should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = Set(Set("hi"), Set("boom!"), Set())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi"), List("boom!"), List()) should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = List(List("hi"), List("boom!"), List())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi"), List("boom!"), List()) should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = List(List("hi"), List("boom!"), List())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi"), Seq("boom!"), Seq()) should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = Seq(Seq("hi"), Seq("boom!"), Seq())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi"), Seq("boom!"), Seq()) should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = Seq(Seq("hi"), Seq("boom!"), Seq())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]()) should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversableArray[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversableArray[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversableArray[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]()) should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversableArray[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversableArray[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq()) should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq()) should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(Vector("hi"), Vector("boom!"), Vector()) should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = Vector(Vector("hi"), Vector("boom!"), Vector())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(Vector("hi"), Vector("boom!"), Vector()) should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = Vector(Vector("hi"), Vector("boom!"), Vector())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi").par, Set("boom!").par, Set().par).par should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = Set(Set("hi").par, Set("boom!").par, Set().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi").par, Set("boom!").par, Set().par).par should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = Set(Set("hi").par, Set("boom!").par, Set().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi").par, List("boom!").par, List().par).par should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = List(List("hi").par, List("boom!").par, List().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi").par, List("boom!").par, List().par).par should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = List(List("hi").par, List("boom!").par, List().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi").par, Seq("boom!").par, Seq().par).par should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = Seq(Seq("hi").par, Seq("boom!").par, Seq().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi").par, Seq("boom!").par, Seq().par).par should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = Seq(Seq("hi").par, Seq("boom!").par, Seq().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(IndexedSeq("hi").par, IndexedSeq("boom!").par, IndexedSeq().par).par should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = IndexedSeq(IndexedSeq("hi").par, IndexedSeq("boom!").par, IndexedSeq().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(IndexedSeq("hi").par, IndexedSeq("boom!").par, IndexedSeq().par).par should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = IndexedSeq(IndexedSeq("hi").par, IndexedSeq("boom!").par, IndexedSeq().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(collection.mutable.Set("hi"), collection.mutable.Set("boom!"), collection.mutable.Set()) should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = collection.mutable.Set(collection.mutable.Set("hi"), collection.mutable.Set("boom!"), collection.mutable.Set())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(collection.mutable.Set("hi"), collection.mutable.Set("boom!"), collection.mutable.Set()) should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = collection.mutable.Set(collection.mutable.Set("hi"), collection.mutable.Set("boom!"), collection.mutable.Set())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(new collection.mutable.ListBuffer() ++ List("hi"), new collection.mutable.ListBuffer() ++ List("boom!"), new collection.mutable.ListBuffer() ++ List()) should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(new collection.mutable.ListBuffer() ++ List("hi"), new collection.mutable.ListBuffer() ++ List("boom!"), new collection.mutable.ListBuffer() ++ List())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `new collection.mutable.ListBuffer() ++ List(new collection.mutable.ListBuffer() ++ List("hi"), new collection.mutable.ListBuffer() ++ List("boom!"), new collection.mutable.ListBuffer() ++ List()) should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(new collection.mutable.ListBuffer() ++ List("hi"), new collection.mutable.ListBuffer() ++ List("boom!"), new collection.mutable.ListBuffer() ++ List())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(collection.mutable.Seq("hi"), collection.mutable.Seq("boom!"), collection.mutable.Seq()) should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = collection.mutable.Seq(collection.mutable.Seq("hi"), collection.mutable.Seq("boom!"), collection.mutable.Seq())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(collection.mutable.Seq("hi"), collection.mutable.Seq("boom!"), collection.mutable.Seq()) should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = collection.mutable.Seq(collection.mutable.Seq("hi"), collection.mutable.Seq("boom!"), collection.mutable.Seq())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(collection.mutable.IndexedSeq("hi"), collection.mutable.IndexedSeq("boom!"), collection.mutable.IndexedSeq()) should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(collection.mutable.IndexedSeq("hi"), collection.mutable.IndexedSeq("boom!"), collection.mutable.IndexedSeq())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(collection.mutable.IndexedSeq("hi"), collection.mutable.IndexedSeq("boom!"), collection.mutable.IndexedSeq()) should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(collection.mutable.IndexedSeq("hi"), collection.mutable.IndexedSeq("boom!"), collection.mutable.IndexedSeq())
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(collection.mutable.Set("hi").par, collection.mutable.Set("boom!").par, collection.mutable.Set().par).par should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = collection.mutable.Set(collection.mutable.Set("hi").par, collection.mutable.Set("boom!").par, collection.mutable.Set().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Set(collection.mutable.Set("hi").par, collection.mutable.Set("boom!").par, collection.mutable.Set().par).par should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = collection.mutable.Set(collection.mutable.Set("hi").par, collection.mutable.Set("boom!").par, collection.mutable.Set().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List((new collection.mutable.ListBuffer() ++ List("hi")).par, (new collection.mutable.ListBuffer() ++ List("boom!")).par, (new collection.mutable.ListBuffer() ++ List()).par)).par should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List((new collection.mutable.ListBuffer() ++ List("hi")).par, (new collection.mutable.ListBuffer() ++ List("boom!")).par, (new collection.mutable.ListBuffer() ++ List()).par)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `(new collection.mutable.ListBuffer() ++ List((new collection.mutable.ListBuffer() ++ List("hi")).par, (new collection.mutable.ListBuffer() ++ List("boom!")).par, (new collection.mutable.ListBuffer() ++ List()).par)).par should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List((new collection.mutable.ListBuffer() ++ List("hi")).par, (new collection.mutable.ListBuffer() ++ List("boom!")).par, (new collection.mutable.ListBuffer() ++ List()).par)).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(collection.mutable.Seq("hi").par, collection.mutable.Seq("boom!").par, collection.mutable.Seq().par).par should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = collection.mutable.Seq(collection.mutable.Seq("hi").par, collection.mutable.Seq("boom!").par, collection.mutable.Seq().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.Seq(collection.mutable.Seq("hi").par, collection.mutable.Seq("boom!").par, collection.mutable.Seq().par).par should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = collection.mutable.Seq(collection.mutable.Seq("hi").par, collection.mutable.Seq("boom!").par, collection.mutable.Seq().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(collection.mutable.IndexedSeq("hi").par, collection.mutable.IndexedSeq("boom!").par, collection.mutable.IndexedSeq().par).par should throw TestFailedException with correct stack depth and message when 'traversable should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(collection.mutable.IndexedSeq("hi").par, collection.mutable.IndexedSeq("boom!").par, collection.mutable.IndexedSeq().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesSizeEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was not empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `collection.mutable.IndexedSeq(collection.mutable.IndexedSeq("hi").par, collection.mutable.IndexedSeq("boom!").par, collection.mutable.IndexedSeq().par).par should throw TestFailedException with correct stack depth and message when 'traversable should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(collection.mutable.IndexedSeq("hi").par, collection.mutable.IndexedSeq("boom!").par, collection.mutable.IndexedSeq().par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesSizeNotEqualGenTraversable[String](xs, 0) + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} was empty (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi"), Set("boom!"), Set("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have size' failed` {
    val xs = Set(Set("hi"), Set("boom!"), Set("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi"), Set("boom!"), Set("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have size' failed` {
    val xs = Set(Set("hi"), Set("boom!"), Set("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi"), Set("boom!"), Set("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have length' failed` {
    val xs = Set(Set("hi"), Set("boom!"), Set("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi"), Set("boom!"), Set("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have length' failed` {
    val xs = Set(Set("hi"), Set("boom!"), Set("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi"), Set("boom!"), Set("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should contain' failed` {
    val xs = Set(Set("hi"), Set("boom!"), Set("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi"), Set("boom!"), Set("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not contain' failed` {
    val xs = Set(Set("hi"), Set("boom!"), Set("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi"), List("boom!"), List("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have size' failed` {
    val xs = List(List("hi"), List("boom!"), List("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi"), List("boom!"), List("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have size' failed` {
    val xs = List(List("hi"), List("boom!"), List("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi"), List("boom!"), List("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have length' failed` {
    val xs = List(List("hi"), List("boom!"), List("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi"), List("boom!"), List("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have length' failed` {
    val xs = List(List("hi"), List("boom!"), List("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi"), List("boom!"), List("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should contain' failed` {
    val xs = List(List("hi"), List("boom!"), List("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi"), List("boom!"), List("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not contain' failed` {
    val xs = List(List("hi"), List("boom!"), List("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi"), Seq("boom!"), Seq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have size' failed` {
    val xs = Seq(Seq("hi"), Seq("boom!"), Seq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi"), Seq("boom!"), Seq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have size' failed` {
    val xs = Seq(Seq("hi"), Seq("boom!"), Seq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi"), Seq("boom!"), Seq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have length' failed` {
    val xs = Seq(Seq("hi"), Seq("boom!"), Seq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi"), Seq("boom!"), Seq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have length' failed` {
    val xs = Seq(Seq("hi"), Seq("boom!"), Seq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi"), Seq("boom!"), Seq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should contain' failed` {
    val xs = Seq(Seq("hi"), Seq("boom!"), Seq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi"), Seq("boom!"), Seq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not contain' failed` {
    val xs = Seq(Seq("hi"), Seq("boom!"), Seq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have size' failed` {
    val xs = Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversableArray[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversableArray[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversableArray[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have size' failed` {
    val xs = Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversableArray[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversableArray[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversableArray[String](itr, xs, 1)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have length' failed` {
    val xs = Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversableArray[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversableArray[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversableArray[String](itr, xs, 0)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have length' failed` {
    val xs = Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversableArray[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversableArray[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversableArray[String](itr, xs, 1)) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should contain' failed` {
    val xs = Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesContainGenTraversableArray[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversableArray[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversableArray[String](itr, xs, "hi")) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not contain' failed` {
    val xs = Array[Array[String]](Array[String]("hi"), Array[String]("boom!"), Array[String]("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotContainGenTraversableArray[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementContainGenTraversableArray[String](itr, xs, "hi")) + " \n" + 
  "in " + arrayToString(xs))
  }
  def `IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have size' failed` {
    val xs = IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have size' failed` {
    val xs = IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have length' failed` {
    val xs = IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have length' failed` {
    val xs = IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should contain' failed` {
    val xs = IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not contain' failed` {
    val xs = IndexedSeq(IndexedSeq("hi"), IndexedSeq("boom!"), IndexedSeq("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Vector(Vector("hi"), Vector("boom!"), Vector("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have size' failed` {
    val xs = Vector(Vector("hi"), Vector("boom!"), Vector("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(Vector("hi"), Vector("boom!"), Vector("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have size' failed` {
    val xs = Vector(Vector("hi"), Vector("boom!"), Vector("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Vector(Vector("hi"), Vector("boom!"), Vector("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should have length' failed` {
    val xs = Vector(Vector("hi"), Vector("boom!"), Vector("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Vector(Vector("hi"), Vector("boom!"), Vector("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not have length' failed` {
    val xs = Vector(Vector("hi"), Vector("boom!"), Vector("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Vector(Vector("hi"), Vector("boom!"), Vector("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should contain' failed` {
    val xs = Vector(Vector("hi"), Vector("boom!"), Vector("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Vector(Vector("hi"), Vector("boom!"), Vector("hello")) should throw TestFailedException with correct stack depth and message when 'traversable should not contain' failed` {
    val xs = Vector(Vector("hi"), Vector("boom!"), Vector("hello"))
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi").par, Set("boom!").par, Set("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should have size' failed` {
    val xs = Set(Set("hi").par, Set("boom!").par, Set("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi").par, Set("boom!").par, Set("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should not have size' failed` {
    val xs = Set(Set("hi").par, Set("boom!").par, Set("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi").par, Set("boom!").par, Set("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should have length' failed` {
    val xs = Set(Set("hi").par, Set("boom!").par, Set("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi").par, Set("boom!").par, Set("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should not have length' failed` {
    val xs = Set(Set("hi").par, Set("boom!").par, Set("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi").par, Set("boom!").par, Set("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should contain' failed` {
    val xs = Set(Set("hi").par, Set("boom!").par, Set("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Set(Set("hi").par, Set("boom!").par, Set("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should not contain' failed` {
    val xs = Set(Set("hi").par, Set("boom!").par, Set("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi").par, List("boom!").par, List("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should have size' failed` {
    val xs = List(List("hi").par, List("boom!").par, List("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi").par, List("boom!").par, List("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should not have size' failed` {
    val xs = List(List("hi").par, List("boom!").par, List("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi").par, List("boom!").par, List("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should have length' failed` {
    val xs = List(List("hi").par, List("boom!").par, List("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have length 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi").par, List("boom!").par, List("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should not have length' failed` {
    val xs = List(List("hi").par, List("boom!").par, List("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had length 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi").par, List("boom!").par, List("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should contain' failed` {
    val xs = List(List("hi").par, List("boom!").par, List("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should contain ("hi")
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 1 element satisfied the assertion block at " + succeededIndexesContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not contain element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementNotContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `List(List("hi").par, List("boom!").par, List("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should not contain' failed` {
    val xs = List(List("hi").par, List("boom!").par, List("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not contain "hi"
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because only 2 elements satisfied the assertion block at " + succeededIndexesNotContainGenTraversable[String](xs, "hi") + ": \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} contained element \"hi\" (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementContainGenTraversable[String](itr, xs, "hi")) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi").par, Seq("boom!").par, Seq("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should have size' failed` {
    val xs = Seq(Seq("hi").par, Seq("boom!").par, Seq("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} did not have size 0 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeNotEqualGenTraversable[String](itr, xs, 0)) + " \n" + 
  "in " + xs)
  }
  def `Seq(Seq("hi").par, Seq("boom!").par, Seq("hello").par).par should throw TestFailedException with correct stack depth and message when 'traversable should not have size' failed` {
    val xs = Seq(Seq("hi").par, Seq("boom!").par, Seq("hello").par).par
    val itr = xs.toIterator
    val e = intercept[exceptions.TestFailedException] {
      exactly(3, xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkError(e, assertLineNumber, "InspectorShorthandsForExactlyFailedSpec1.scala", "forExactly(3) failed, because no element satisfied the assertion block: \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + ", \n" + 
  "  " + new java.text.MessageFormat("at index {0}, {1} had size 1 (InspectorShorthandsForExactlyFailedSpec1.scala:" + assertLineNumber + ")").format(indexElementSizeEqualGenTraversable[String](itr, xs, 1)) + " \n" + 
  "in " + xs)
  }
}
